@@ -1,9 +1,9 @@
-#' Convert a data frame into form suitable for upload to a SQL database
+#' Convert a data frame into form suitable for upload to an SQL database
 #'
 #' This is a generic method that coerces R objects into vectors suitable for
 #' upload to the database. The output will vary a little from method to
 #' method depending on whether the main upload device is through a single
-#' SQL string or multiple parameterised queries.
+#' SQL string or multiple parameterized queries.
 #' This method is mostly useful for backend implementers.
 #'
 #' The default method:
@@ -25,9 +25,11 @@
 #' sqlData(con, head(mtcars))
 #'
 #' dbDisconnect(con)
-setGeneric("sqlData", function(con, value, row.names = NA, ...) {
-  standardGeneric("sqlData")
-})
+setGeneric(
+  "sqlData",
+  function(con, value, row.names = NA, ...)
+    standardGeneric("sqlData")
+)
 
 #' @rdname hidden_aliases
 #' @export
