@@ -1,14 +1,14 @@
 #' Insert rows into a table
 #'
-#' \code{sqlAppendTable} generates a single SQL string that inserts a
-#' data frame into an existing table. \code{sqlAppendTableTemplate} generates
-#' a template suitable for use with \code{\link{dbBind}}.
+#' `sqlAppendTable` generates a single SQL string that inserts a
+#' data frame into an existing table. `sqlAppendTableTemplate` generates
+#' a template suitable for use with [dbBind()].
 #' These methods are mostly useful for backend implementers.
 #'
 #' @inheritParams sqlCreateTable
 #' @inheritParams rownames
 #' @param values A data frame. Factors will be converted to character vectors.
-#'   Character vectors will be escaped with \code{\link{dbQuoteString}}.
+#'   Character vectors will be escaped with [dbQuoteString()].
 #' @family SQL generation
 #' @export
 #' @examples
@@ -16,10 +16,11 @@
 #'
 #' sqlAppendTable(ANSI(), "mtcars", head(mtcars))
 #' sqlAppendTable(ANSI(), "mtcars", head(mtcars), row.names = FALSE)
-setGeneric("sqlAppendTable", function(con, table, values, row.names = NA,
-                                          ...) {
-  standardGeneric("sqlAppendTable")
-})
+setGeneric(
+  "sqlAppendTable",
+  function(con, table, values, row.names = NA, ...)
+    standardGeneric("sqlAppendTable")
+)
 
 #' @rdname hidden_aliases
 #' @export
